package
Version:
v1.9.1
Opens a new window with list of versions in this module.
Published: Apr 3, 2026
License: MIT
Opens a new window with license information.
Imports: 12
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
RenderInput renders the input view.
func RenderSelection(m model) string
RenderSelection renders the selection menu.
UpdateInput handles text input updates.
UpdateSelection handles navigation in the selection menu.
type Resource struct {
Count int `json:"count"`
Next string `json:"next"`
Previous interface{} `json:"previous"`
Results []Result `json:"results"`
}
type Result struct {
Name string `json:"name"`
URL string `json:"url"`
}
Result is a resources list result.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.